/**
 * This file is yet under development. Please use at your own risk. 
 *
 * Zerjillo
 */
package com.zerjio.JIRC;

import java.net.*;
import java.io.*;

/**
 * A class that allows the basic communication between an IRC Client and
 * an IRC Server.
 *
 * It can <code>connect</code> and <code>disconnect</code> from the server,
 * and it can <code>read</code> and <code>write</code>.
 *
 * @author  Zerjillo (http://www.zerjio.com)
 * @version 0.9b
 */
public class IRCConnection {
  /** The socket that connects the IRC Client with the IRC Server */
  private Socket socket;
  /** To read messages from the IRC Server
   *  @see #read()
   */
  private InputStream input;
  /** To write messages to the IRC Server
   *  @see #write(byte[] msg)
   */
  private OutputStream output;
  
  /**
   * Creates a connection between the IRC Client and a specified IRC Server,
   * which can be used to <code>read()</code> and <code>write(...)</code> to it.
   *
   * @param     server  The server name, or <code>null</code> for the loopback address.
   * @param     port    The port number.
   * @throws    IOException
   *              if there was a problem when trying to connect to the IRC server.
   * @see       #read()
   * @see       #write(byte[] msg)
   */
  protected IRCConnection(String server, int port) throws IOException {
    socket = new Socket(server, port);
    input = socket.getInputStream();
    output = socket.getOutputStream();
  }
  
  /**
   * Checks if the connection is closed.
   *
   * @return  <code>true</code> if the connection is closed (no further writing nor reading).
   *          <code>false</code> if the connection is NOT closed (writing and reading allowed).
   */
  protected boolean isClosed() {
    return socket.isClosed();
  }
  
  /**
   * Turn off the connection, not allowing more writings nor readings.
   *
   * @throws IOException
   *          if there was an error when disconnecting.
   */
  protected void disconnect() throws IOException {
    if (!isClosed()) {
      socket.close();
    }
  }
  
  /**
   * Reads the available bytes sent by the server.
   *
   * @return  The available bytes sent by the server, or <code>null</code> if there
   *          are no available bytes.
   */
  protected byte[] read() {
    byte[] readed = null;
    
    try {
      int available = input.available();
      
      if (available == 0) {
        return null;
      }
      
      readed = new byte[available];
      
      input.read(readed);
    } catch (IOException e) {
      System.err.println("Error when reading from socket.");
      e.printStackTrace(System.err);
    }
    
    return readed;
  }
  
  /**
   * Sends information to the IRC Server.
   *
   * @param     msg   The bytes that must be send to the IRC Server.
   * @return    <code>true</code> if the message were sent without problem
   *            <code>false</code> if there was some error sending the message.
   */
  protected boolean write(byte[] msg) {
    try {
      output.write(msg);
    } catch(IOException e) {
      System.err.println("Error when writing to socket.");
      return false;
    }
    
    return true;
  }
}
