/**
 * This file is yet under development. Please use at your own risk.
 *
 * Zerjillo
 */
package com.zerjio.JIRC;

/**
 * A basic <code>PINGListener</code> that replies with a PONG message every time
 * it receives a <code>PINGMessage</code>.
 *
 * @author  Zerjillo (http://www.zerjio.com)
 * @version 0.9b
 */
public class SimplePINGListener implements PINGListener {
  /** The client used to send the PONG replies */
  private IRCClient client;
  /** Marks if the <code>PINGMessage</code>s should be removed (not processed by more listeners. */
  private boolean removePINGMessages;
  
  /** 
   * Constructs a <code>SimplePINGListener</code>.
   *
   * @param   client  The <code>IRCClient</code> that will be used to send
   *                  the PONG replies.
   * @param   removePINGMessages  Marks if the <code>PINGMessage</code>s should 
   *                              be removed (not processed by more listeners.
   */
  public SimplePINGListener(IRCClient client, boolean removePINGMessages) {
    this.client = client;
    this.removePINGMessages = removePINGMessages;
  }
  
  /** 
   * Constructs a <code>SimplePINGListener</code>. The <code>PINGMessage</code>s
   * will not be removed (and then can be processed by other listeners).
   *
   * @param   client  The <code>IRCClient</code> that will be used to send
   *                  the PONG replies.
   */  
  public SimplePINGListener(IRCClient client) {
    this.client = client;
    this.removePINGMessages = false;
  }
  
  /**
   * Handles a <code>PINGMessage</code> by sending a PONG message with the same
   * parameters as the <code>PINGMessage</code> has. It marks the message as used
   * and sets it to beDiscarded if neceessary.
   *
   * @param   msg   The <code>PINGMessage</code> that has been received.
   */
  public void PINGReceived(PINGMessage msg) {
    client.sendPONGMessage(msg.getParams());
    
    msg.markAsUsed();
    
    if (removePINGMessages) {
      msg.mustBeDiscarded();
    }
  }
}
