/**
 * This file is yet under development. Please use at your own risk.
 *
 * Zerjillo
 */
package com.zerjio.JIRC;

/**
 * This class represents a TOPIC message that is send over an IRC Connection.
 * <P>
 * It is recommended to take a look to the RFC 1459 to know what this message
 * means, its exact format and how to handle it.
 *
 * @author  Zerjillo (http://www.zerjio.com)
 * @version 0.9b
 */
public class TOPICMessage extends IRCMessage {
  /**
   * Constructs a TOPIC message with a prefix and its parameters.
   * The <code>command</code> will be <code>TOPIC</code>.
   *
   * @param   prefix    The TOPIC message prefix.
   * @param   params    The TOPIC message parameters.
   */
  public TOPICMessage(String prefix, String params) {
    super(prefix, "TOPIC", params);
  }
  
  /**
   * Returns the nick of the one who has changed the topic
   *
   * @return    The nick that changes the topic
   */
  public String whoChangesTopic() {
    return getNick();
  }
  
  /**
   * Returns the topic of the channel.
   *
   * @return    The topic of the channel.
   */
  public String getTopic() {
    String aux = getParams();
    
    int pos = aux.indexOf(':');
    
    return aux.substring(pos + 1);
  }
  
  /**
   * Returns the channel name of the topic message.
   *
   * @return    The name of the channel that has the topic.
   */
  public String getChannelName() {
    String aux = getParams();
    
    int pos = aux.indexOf(' ');
    
    return aux.substring(0, pos);
  }
}
