/**
 * This file is yet under development. Please use at your own risk.
 *
 * Zerjillo
 */
package com.zerjio.JIRC;

/**
 * A general utilities class. All its methods should be static.
 *
 * @author  Zerjillo (http://www.zerjio.com)
 * @version 0.9b
 */
public class Utils {
  /**
   * Checks if a command string is a reply message command (a 3 digit number).
   *
   * @return    <code>true</code> if the command corresponds to a reply message.
   *            <code>false</code> otherwise.
   */
  public static boolean isReplyMessage(String command) {
    if (command.length() != 3) {
      return false;
    }
    
    if (!Character.isDigit(command.charAt(0))) {
      return false;
    }
    
    if (!Character.isDigit(command.charAt(1))) {
      return false;
    }
    
    if (!Character.isDigit(command.charAt(2))) {
      return false;
    }
    
    return true;
  }
  
  /**
   * Counts the number of ocurrences of a char into a given string.
   *
   * @param   character   The character that should be count.
   * @param   string      The string where the character should be counted.
   *
   * @return    The number of ocurrences of the <code>character</code> into the given <code>string</code>.
   */
  public static int countChar(char character, String string) {
    int pointer = 0;
    int count = 0;
    
    pointer = string.indexOf(character, pointer);
    while(pointer != -1) {
      count++;
      pointer = string.indexOf(character, pointer + 1);
    }
    
    return count;
  }
  
  /**
   * Splits a given string into one or more which are separated by a given separator
   * character.
   *
   * @param   separatorChar   The char which separates the different substrings
   * @param   string          The string that must be splitted
   *
   * @return    An array of strings which were on <code>string</code> but separated with the
   *            <code>separatorChar</code>.
   */
  public static String[] splitString(char separatorChar, String string) {
    String[] result = new String[countChar(separatorChar, string) + 1];
    
    for (int i = 0 ; i < result.length - 1; i++) {
      int nextIndex = string.indexOf(separatorChar);
      result[i] = string.substring(0, nextIndex);
      string = string.substring(nextIndex + 1);
    }
    
    result[result.length - 1] = string;
    
    return result;
  }
  
  /**
   * Tests if two nicks are equivalent.
   *
   * @param   nick1   The first nick to compare
   * @param   nick2   The second nick to compare
   *
   * @return    <code>true</code> if both nicks are equivalent.
   *            <code>false</code> otherwise.
   */
  public static boolean areNicksEquivalent(String nick1, String nick2) {
    nick1 = nick1.replace('{', '[');
    nick2 = nick2.replace('{', '[');
    nick1 = nick1.replace('}', ']');
    nick2 = nick2.replace('}', ']');
    
    nick1 = nick1.toUpperCase();
    nick2 = nick2.toUpperCase();
    
    return (nick1.compareTo(nick2) == 0);
  }
  
  /**
   * Tests if two channel names are equivalent.
   *
   * @param   channelName1   The first channel name to compare
   * @param   channelName2   The second channel name to compare
   *
   * @return    <code>true</code> if both channels names are equivalent.
   *            <code>false</code> otherwise.
   */
  public static boolean areChannelsEquivalent(String channelName1, String channelName2) {
    return areNicksEquivalent(channelName1, channelName2);
  }
}
